==> jme3-plugins-3.3.2-stable-sources.jar: com/jme3/scene/plugins/ogre/matext/MaterialExtension.java <==
/*
 * Copyright (c) 2009-2019 jMonkeyEngine
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 * * Redistributions of source code must retain the above copyright
 *   notice, this list of conditions and the following disclaimer.
 *
 * * Redistributions in binary form must reproduce the above copyright
 *   notice, this list of conditions and the following disclaimer in the
 *   documentation and/or other materials provided with the distribution.
 *
 * * Neither the name of 'jMonkeyEngine' nor the names of its contributors
 *   may be used to endorse or promote products derived from this software
 *   without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
 * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED
 * TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR
 * CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
 * PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
 * LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
 * NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 * SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */
package com.jme3.scene.plugins.ogre.matext;

import java.util.HashMap;

/**
 * <code>MaterialExtension</code> defines a mapping from an Ogre3D "base" material
 * to a jME3 material definition.
 */
public class MaterialExtension {

    private String baseMatName;
    private String jmeMatDefName;
    private HashMap<String, String> textureMappings = new HashMap<String, String>();

    /**
     * Material extension defines a mapping from an Ogre3D "base" material
     * to a jME3 material definition.
     *
     * @param baseMatName The base material name for Ogre3D
     * @param jmeMatDefName The material definition name for jME3
     */
    public MaterialExtension(String baseMatName, String jmeMatDefName) {
        this.baseMatName = baseMatName;
        this.jmeMatDefName = jmeMatDefName;
    }

    public String getBaseMaterialName() {
        return baseMatName;
    }

    public String getJmeMatDefName() {
        return jmeMatDefName;
    }

    /**
     * Set mapping from an Ogre3D base material texture alias to a
     * jME3 texture param
     * @param ogreTexAlias The texture alias in the Ogre3D base material
     * @param jmeTexParam The texture param name in the jME3 material definition.
     */
    public void setTextureMapping(String ogreTexAlias, String jmeTexParam){
        textureMappings.put(ogreTexAlias, jmeTexParam);
    }

    /**
     * Retrieves a mapping from an Ogre3D base material texture alias
     * to a jME3 texture param
     * @param ogreTexAlias The texture alias in the Ogre3D base material
     * @return The texture alias in the Ogre3D base material
     */
    public String getTextureMapping(String ogreTexAlias){
        return textureMappings.get(ogreTexAlias);
    }
}

==> jme3-plugins-3.8.0-stable-sources.jar: com/jme3/scene/plugins/ogre/matext/MaterialExtension.java <==
/*
 * Copyright (c) 2009-2021 jMonkeyEngine
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 * * Redistributions of source code must retain the above copyright
 *   notice, this list of conditions and the following disclaimer.
 *
 * * Redistributions in binary form must reproduce the above copyright
 *   notice, this list of conditions and the following disclaimer in the
 *   documentation and/or other materials provided with the distribution.
 *
 * * Neither the name of 'jMonkeyEngine' nor the names of its contributors
 *   may be used to endorse or promote products derived from this software
 *   without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
 * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED
 * TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR
 * CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
 * PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
 * LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
 * NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 * SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */
package com.jme3.scene.plugins.ogre.matext;

import java.util.HashMap;

/**
 * <code>MaterialExtension</code> defines a mapping from an Ogre3D "base" material
 * to a jME3 material definition.
 */
public class MaterialExtension {

    private String baseMatName;
    private String jmeMatDefName;
    private HashMap<String, String> textureMappings = new HashMap<>();

    /**
     * Material extension defines a mapping from an Ogre3D "base" material
     * to a jME3 material definition.
     *
     * @param baseMatName The base material name for Ogre3D
     * @param jmeMatDefName The material definition name for jME3
     */
    public MaterialExtension(String baseMatName, String jmeMatDefName) {
        this.baseMatName = baseMatName;
        this.jmeMatDefName = jmeMatDefName;
    }

    public String getBaseMaterialName() {
        return baseMatName;
    }

    public String getJmeMatDefName() {
        return jmeMatDefName;
    }

    /**
     * Set mapping from an Ogre3D base material texture alias to a
     * jME3 texture param
     * @param ogreTexAlias The texture alias in the Ogre3D base material
     * @param jmeTexParam The texture param name in the jME3 material definition.
     */
    public void setTextureMapping(String ogreTexAlias, String jmeTexParam){
        textureMappings.put(ogreTexAlias, jmeTexParam);
    }

    /**
     * Retrieves a mapping from an Ogre3D base material texture alias
     * to a jME3 texture param
     * @param ogreTexAlias The texture alias in the Ogre3D base material
     * @return The texture alias in the Ogre3D base material
     */
    public String getTextureMapping(String ogreTexAlias){
        return textureMappings.get(ogreTexAlias);
    }
}
